==> mariadb-connector-java_2.3.0.orig.tar.xz: mariadb-connector-j-2.3.0/src/test/java/org/mariadb/jdbc/MariaDbCompatibilityTest.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2017 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.sql.Types;
import org.junit.BeforeClass;
import org.junit.Test;

public class MariaDbCompatibilityTest extends BaseTest {

  /**
   * Preparation.
   *
   * @throws SQLException exception
   */
  @BeforeClass()
  public static void initClass() throws SQLException {
    createTable("datatypesTest", "type_longvarchar TEXT NULL");
    createTable("mysqlcompatibilitytest",
        "id int not null primary key auto_increment, test bit(1)");
  }

  /**
   * Conj-82: data type LONGVARCHAR not supported in setObject().
   *
   * @throws SQLException exception
   */
  @Test
  public void datatypesTest() throws SQLException {
    try (Statement stmt = sharedConnection.createStatement()) {
      try (PreparedStatement preparedStmt = sharedConnection.prepareStatement(
          "INSERT INTO `datatypesTest` (`type_longvarchar`) VALUES ( ? )")) {
        preparedStmt.setObject(1, "longvarcharTest", Types.LONGVARCHAR);
        preparedStmt.executeUpdate();
      }

      ResultSet rs = stmt.executeQuery("SELECT * FROM datatypesTest");
      stmt.close();
      if (rs.next()) {
        assertEquals("longvarcharTest", rs.getString(1));
      } else {
        fail();
      }
    }
  }

  /**
   * The Mysql connector returns "0" or "1" for BIT(1) with ResultSet.getString(). CONJ-102:
   * mariadb-java-client returned "false" or "true".
   *
   * @throws SQLException exception
   */
  @Test
  public void testBitConj102() throws SQLException {
    Statement stmt = sharedConnection.createStatement();
    stmt.execute("insert into mysqlcompatibilitytest values(null, b'0')");
    stmt.execute("insert into mysqlcompatibilitytest values(null, b'1')");
    ResultSet rs = stmt.executeQuery("select * from mysqlcompatibilitytest");
    assertTrue(rs.next());
    assertTrue("0".equalsIgnoreCase(rs.getString(2)));
    assertTrue(rs.next());
    assertTrue("1".equalsIgnoreCase(rs.getString(2)));
  }

}

==> mariadb-connector-java_2.5.3.orig.tar.xz: mariadb-connector-j-2.5.3/src/test/java/org/mariadb/jdbc/MariaDbCompatibilityTest.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2019 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc;

import org.junit.*;

import java.sql.*;

import static org.junit.Assert.*;

public class MariaDbCompatibilityTest extends BaseTest {

  /**
   * Preparation.
   *
   * @throws SQLException exception
   */
  @BeforeClass()
  public static void initClass() throws SQLException {
    createTable("datatypesTest", "type_longvarchar TEXT NULL");
    createTable(
        "mysqlcompatibilitytest", "id int not null primary key auto_increment, test bit(1)");
  }

  /**
   * Conj-82: data type LONGVARCHAR not supported in setObject().
   *
   * @throws SQLException exception
   */
  @Test
  public void datatypesTest() throws SQLException {
    try (Statement stmt = sharedConnection.createStatement()) {
      try (PreparedStatement preparedStmt =
          sharedConnection.prepareStatement(
              "INSERT INTO `datatypesTest` (`type_longvarchar`) VALUES ( ? )")) {
        preparedStmt.setObject(1, "longvarcharTest", Types.LONGVARCHAR);
        preparedStmt.executeUpdate();
      }

      ResultSet rs = stmt.executeQuery("SELECT * FROM datatypesTest");
      stmt.close();
      if (rs.next()) {
        assertEquals("longvarcharTest", rs.getString(1));
      } else {
        fail();
      }
    }
  }

  /**
   * The Mysql connector returns "0" or "1" for BIT(1) with ResultSet.getString(). CONJ-102:
   * mariadb-java-client returned "false" or "true".
   *
   * @throws SQLException exception
   */
  @Test
  public void testBitConj102() throws SQLException {
    Statement stmt = sharedConnection.createStatement();
    stmt.execute("insert into mysqlcompatibilitytest values(null, b'0')");
    stmt.execute("insert into mysqlcompatibilitytest values(null, b'1')");
    ResultSet rs = stmt.executeQuery("select * from mysqlcompatibilitytest");
    assertTrue(rs.next());
    assertTrue("0".equalsIgnoreCase(rs.getString(2)));
    assertTrue(rs.next());
    assertTrue("1".equalsIgnoreCase(rs.getString(2)));
  }
}
